@@ -142,7 +142,7 @@ int getAnalyticalJacobianUmfPack(DATA* data, threadData_t *threadData, int sysNu
   ANALYTIC_JACOBIAN* parentJacobian = systemData->parDynamicData[omc_get_thread_num()].parentJacobian;
 
   int nth = 0;
-  int nnz = jacobian->sparsePattern->numberOfNoneZeros;
+  int nnz = jacobian->sparsePattern->numberOfNonZeros;
 
   for(i=0; i < jacobian->sizeRows; i++)
   {
