@@ -56,8 +56,10 @@ public:
   static QString organization;
   static QString application;
   static QString OpenModelicaVersion;
+  static QString OpenModelicaUsersGuideVersion;
   static QString OpenModelicaHome;
-  static QString OpenModelicaLibrary;
+  static QString ModelicaPath;
+  static QString userHomeDirectory;
   static QString OMCServerName;
   static QString omFileTypes;
   static QString omEncryptedFileTypes;
@@ -76,8 +78,8 @@ public:
   static QString txtFileTypes;
   static QString figaroFileTypes;
   static QString visualizationFileTypes;
-  static QString omsFileTypes;
   static QString subModelFileTypes;
+  static QString omScriptTypes;
   static int treeIndentation;
   static QSize iconSize;
   static int tabWidth;
@@ -151,6 +153,7 @@ public:
   static QString error;
   static QString chooseFile;
   static QString chooseFiles;
+  static QString saveFile;
   static QString attributes;
   static QString properties;
   static QString add;
@@ -211,6 +214,7 @@ public:
   static QString resetZoom;
   static QString zoomIn;
   static QString zoomOut;
+  static QString fitToDiagram;
   static QString loading;
   static QString question;
   static QString search;
@@ -347,10 +351,11 @@ public:
   static QString stepReturn;
   static QString attachToRunningProcess;
   static QString attachToRunningProcessTip;
-  static QString crashReport;
+  static QString reportIssue;
   static QString parsingFailedJson;
   static QString expandAll;
   static QString collapseAll;
+  static QString versionLabel;
   static QString version;
   static QString unlimited;
   static QString simulationOutput;
@@ -420,12 +425,16 @@ public:
   static QString stopTime;
   static QString status;
   static QString speed;
-  static QString instantiateOMSModelTip;
   static QString terminateInstantiation;
   static QString terminateInstantiationTip;
   static QString archivedSimulations;
   static QString systemSimulationInformation;
   static QString translationFlags;
+  static QString send;
+  static QString installLibrary;
+  static QString upgradeInstalledLibraries;
+  static QString updateLibraryIndex;
+  static QString dataReconciliation;
 };
 
 class GUIMessages : public QObject
@@ -500,7 +509,8 @@ public:
     MULTIPLE_DECLARATIONS_COMPONENT,
     GDB_ERROR,
     INVALID_INSTANCE_NAME,
-    ENTER_SCRIPT
+    ENTER_SCRIPT,
+    LIBRARY_INDEX_FILE_NOT_FOUND
   };
 
   static QString getMessage(int type);
